@@ -22,8 +22,9 @@ from typing import List
 import loguru
 from munch import Munch
 from tabulate import tabulate
+from runpodpy import CloudType, GPUTypeId
 
-from runpodpy.runpod import RunPod, RunPodException, RunPodInstance
+from runpodpy.runpod import OutbidException, RunPod, RunPodException, RunPodInstance
 
 
 async def stop(runpod: RunPod, config: Munch, logger: loguru.Logger) -> None:
@@ -98,30 +99,57 @@ async def create(runpod: RunPod, config: Munch, logger: loguru.Logger) -> None:
         podName: str = config["machine"]["gpuTypeId"].replace(" ", "_") + str(len(pods))
 
         config.machine["podName"] = podName
+    
+    config.machine["gpuTypeId"] = GPUTypeId(config.machine["gpuTypeId"])
+    config["cloudType"] = CloudType[config["cloudType"].upper()]
 
-    # Create a pod if there are no pods
-    if config.machine.get("templateId") is None:
-        pod = await runpod.create_instance(
-            config.max_bid,
-            *config.machine,
-            logger,
-            spot=config.spot,
-        )
-    else:
-        # Create a pod from a template
-        pod = await runpod.create_instance_from_template(
-            config.max_bid,
-            *config.machine,
-            logger,
-            spot=config.spot,
-        )
+    if config.get("max_bid") is None:
+        logger.exception("No --max_bid specified")
+        return
+    try:
+        # Create a pod if there are no pods
+        if config.machine.get("templateId") is None:
+            pod = await runpod.create_instance(
+                config.max_bid,
+                config.machine["podName"],
+                config.machine["imageName"],
+                config.machine["containerDiskSize"],
+                config.machine["volumeSize"],
+                config.machine["volumePath"],
+                config.machine["gpuCount"],
+                config.machine["gpuTypeId"],
+                config.machine["minVcpuCount"],
+                config.machine["minMemoryInGb"],
+                logger,
+                cloudType=config.cloudType,
+                spot=config.spot,
+            )
+        else:
+            # Create a pod from a template
+            pod = await runpod.create_instance_from_template_id(
+                config.max_bid,
+                config.machine.get("podName"),
+                config.machine.get("templateId"),
+                config.machine.get("containerDiskSize"),
+                config.machine.get("volumeSize"),
+                config.machine.get("gpuCount"),
+                config.machine.get("gpuTypeId"),
+                config.machine.get("minVcpuCount"),
+                config.machine.get("minMemoryInGb"),
+                logger,
+                cloudType=config.cloudType,
+                spot=config.spot,
+            )
+    except OutbidException as e:
+        logger.error(e)
+        pod = None
         
     if pod is None:
         logger.error(
-            f"Failed to create pod - max_bid:{config.max_bid} spot:{config.spot}"
+            f"Failed to create {config.cloudType} pod - max_bid:{config.max_bid} spot:{config.spot}"
         )
     else:
-        logger.info(f"Created pod {pod.podId}")
+        logger.info(f"Created {config.cloudType} pod {pod.podId}")
 
 
 async def destroy(runpod: RunPod, config: Munch, logger: loguru.Logger) -> None:
@@ -164,6 +192,7 @@ async def list_pods(runpod: RunPod, config: Munch, logger: loguru.Logger) -> Non
             [
                 "podId",
                 "podName",
+                "cloudType",
                 "instanceType",
                 "gpuTypeId",
                 "gpuCount",
@@ -176,10 +205,11 @@ async def list_pods(runpod: RunPod, config: Munch, logger: loguru.Logger) -> Non
                 [
                     pod.podId,
                     pod.podName,
+                    pod.cloudType,
                     "SPOT" if pod.spot else "ON_DEMAND",
                     pod.gpuDisplayName,
                     pod.gpuCount,
-                    pod.cost,
+                    f"${pod.cost:.2f}/hr",
                     pod.ip_address,
                 ]
                 for pod in pods
